.. yagmail documentation master file, created by
   sphinx-quickstart on Tue Sep 19 19:40:28 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

yagmail
=======
`yagmail` is a GMAIL/SMTP client that aims to
make it as simple as possible to send emails.

.. toctree::
   :maxdepth: 2

   api
   setup
   usage



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
